@@ -20,12 +20,12 @@
 #    along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
 
 # this script will use srvrmgr program to connect to a given Siebel Server,
-# list it's components available and print a set of 'create component definition'
+# list it's components available and print to STDOUT a set of 'create component definition'
 # commands of the respective components
 
 use warnings;
 use strict;
-use Siebel::Srvrmgr::Daemon::Heavy;
+use Siebel::Srvrmgr::Daemon;
 use Siebel::Srvrmgr::ListParser::Output::ListComp::Server;
 use Siebel::Srvrmgr::ListParser::Output::ListParams;
 use Siebel::Srvrmgr::Daemon::Command;
@@ -34,12 +34,10 @@ use Siebel::Srvrmgr::Exporter::ListComp;
 use Siebel::Srvrmgr::Exporter::ListCompTypes;
 use File::Spec;
 use Getopt::Std;
+use feature qw(say);
 use Term::Pulse;
 
-$Getopt::Std::STANDARD_HELP_VERSION = 2;
-
-# for stopping Term::Pulse correctly
-$SIG{INT} = sub { die "Caught interrupt signal" };
+$Getopt::Std::STANDARD_HELP_VERSION = 1;
 
 our $VERSION = 1;
 
@@ -49,11 +47,11 @@ sub HELP_MESSAGE {
 
     if ( ( defined($option) ) and ( ref($option) eq '' ) ) {
 
-        print "'-$option' parameter cannot be null\n";
+        say "'-$option' parameter cannot be null";
 
     }
 
-    print <<BLOCK;
+    say <<BLOCK;
 
 export_comps - version $VERSION
 
@@ -68,14 +66,12 @@ The parameters below are obligatory:
 	-e: expects as parameter the Siebel Enterprise name as parameter
 	-u: expects as parameter the user for authentication as parameter
 	-p: expects as parameter the password for authentication as parameter
-	-b: expects as parameter the complete path to the srvrmgr binary file as parameter
+	-b: expects as parameter the complete path to the srvrmgr program as parameter
 	-r: expects as parameter the regular expression to match component alias to export as parameter (case sensitive)
 
 The parameters below are optional:
 
-	-x: exclude mode. If present, the program will exclude component parameters with empty values from the generated 'created component' command
-	-q: quiet mode. If present, the program will not put print anything to STDOUT but the "create component" output (see also -o)
-	-o: output mode. If present, expects a filename as parameter to print the output to this file instead of STDOUT (default)
+	-x: if present, the program will exclude component parameters with empty values from the generated 'created component' command
 	-h: prints this help message and exists
 
 BLOCK
@@ -86,7 +82,7 @@ BLOCK
 
 our %opts;
 
-getopts( 's:g:e:u:p:b:r:o:xhq', \%opts );
+getopts( 's:g:e:u:p:b:r:xh', \%opts );
 
 HELP_MESSAGE() if ( exists( $opts{h} ) );
 
@@ -100,19 +96,19 @@ pulse_start(
     name   => 'Connecting to Siebel and getting initial data...',
     rotate => 1,
     time   => 1
-) unless ( $opts{q} );
+);
 
-my $daemon = Siebel::Srvrmgr::Daemon::Heavy->new(
+my $daemon = Siebel::Srvrmgr::Daemon->new(
     {
-        server       => $opts{s},
-        gateway      => $opts{g},
-        enterprise   => $opts{e},
-        user         => $opts{u},
-        password     => $opts{p},
-        bin          => $opts{b},
-        is_infinite  => 0,
-        read_timeout => 5,
-        commands     => [
+        server      => $opts{s},
+        gateway     => $opts{g},
+        enterprise  => $opts{e},
+        user        => $opts{u},
+        password    => $opts{p},
+        bin         => $opts{b},
+        is_infinite => 0,
+        timeout     => 0,
+        commands    => [
             Siebel::Srvrmgr::Daemon::Command->new(
                 {
                     command => 'load preferences',
@@ -123,46 +119,59 @@ my $daemon = Siebel::Srvrmgr::Daemon::Heavy->new(
 # LoadPreferences does not add anything into ActionStash, so it's ok use a second action here
             Siebel::Srvrmgr::Daemon::Command->new(
                 {
-                    command => 'list comp',
-                    action  => 'Siebel::Srvrmgr::Exporter::ListComp'
+                    command => 'list comp type',
+                    action  => 'Siebel::Srvrmgr::Exporter::ListCompTypes'
                 }
-              )
-
+            )
         ]
     }
 );
 
-# "globals"
-my ( $DEFS_REF, $TYPES_REF );
-
 my $stash = Siebel::Srvrmgr::Daemon::ActionStash->instance();
 
 $daemon->run();
+my $comp_types_ref = $stash->get_stash();
+$stash->set_stash( [] );
 
-my $sieb_srv     = $stash->shift_stash();
+$daemon->set_commands(
+    [
+        Siebel::Srvrmgr::Daemon::Command->new(
+            {
+                command => 'list comp def',
+                action  => 'Siebel::Srvrmgr::Exporter::ListCompDef'
+            }
+        )
+    ]
+);
+
+$daemon->run();
+my $comp_defs_ref = $stash->get_stash();
+$stash->set_stash( [] );
+
+$daemon->set_commands(
+    [
+        Siebel::Srvrmgr::Daemon::Command->new(
+            {
+                command => 'list comp',
+                action  => 'Siebel::Srvrmgr::Exporter::ListComp'
+            }
+        )
+    ]
+);
+
+$daemon->run();
+my $sieb_srv = $stash->get_stash();
+$stash->set_stash( [] );
 my $server_comps = $sieb_srv->get_comps();
 
 my $comp_regex = qr/$opts{r}/;
 
-pulse_stop() unless ( $opts{q} );
-
-my $out;
-
-if ( defined( $opts{o} ) ) {
-
-    open( $out, '>:utf8', $opts{o} )
-      or die "Cannot create output file $opts{o}: $!\n";
-
-}
-
-my $no_match = 1;
+pulse_stop();
 
 foreach my $comp_alias ( @{$server_comps} ) {
 
     next unless ( $comp_alias =~ $comp_regex );
 
-    $no_match = 0;
-
     my $command =
         'list params for server '
       . $sieb_srv->get_name()
@@ -181,15 +190,13 @@ foreach my $comp_alias ( @{$server_comps} ) {
     );
 
     $daemon->run();
-    my $params = $stash->shift_stash();
+    my $params = $stash->get_stash();
 
     my $comp = $sieb_srv->get_comp($comp_alias);
 
-# check if the attribute is not already set since the behaviour below was from Siebel 7.5.3 only
-    $comp->ct_name( $comp->cc_name(), $daemon, $stash )
-      unless ( $comp->ct_name() );
-    $comp->ct_alias( $comp->ct_name(), $daemon, $stash )
-      unless ( $comp->ct_alias() );
+    $comp->ct_name( $comp_defs_ref->{ $comp->cc_name() }->{CT_NAME} );
+
+    $comp->ct_alias( $comp_types_ref->{ $comp->ct_name() }->{CT_ALIAS} );
 
     my @params;
 
@@ -208,93 +215,10 @@ foreach my $comp_alias ( @{$server_comps} ) {
 
     }
 
-    if ( defined( $opts{o} ) ) {
-
-        print $out 'create component definition ', $comp->cc_alias(),
-          ' for component type ', $comp->ct_alias(),
-          ' component group ', $comp->cg_alias(), ' run mode ',
-          $comp->cc_runmode(),
-          ' full name "', $comp->cc_name(), '" description "',
-          $comp->cc_desc_text(), '" with parameter ', join( ',', @params ),
-          ";\n";
-
-    }
-    else {
-
-        print "\n", 'create component definition ', $comp->cc_alias(),
-          ' for component type ', $comp->ct_alias(),
-          ' component group ', $comp->cg_alias(), ' run mode ',
-          $comp->cc_runmode(),
-          ' full name "', $comp->cc_name(), '" description "',
-          $comp->cc_desc_text(), '" with parameter ', join( ',', @params ),
-          ";\n\n";
-
-    }
-
-}
-
-close($out) if ( defined($out) );
-
-if ($no_match) {
-
-    warn
-"Could not match any component alias to the string '$opts{r}'. Removing the output file (probably empty anyway)...";
-    unlink( $opts{o} ) or die "Cannot remove $opts{o}: $!\n";
-
-}
-
-sub get_comp_type_alias {
-
-    my $comp_type_name = shift;
-    my $daemon         = shift;
-    my $stash          = shift;
-
-    unless ( defined($TYPES_REF) ) {
-
-        $daemon->set_commands(
-            [
-                Siebel::Srvrmgr::Daemon::Command->new(
-                    {
-                        command => 'list comp type',
-                        action  => 'Siebel::Srvrmgr::Exporter::ListCompTypes'
-                    }
-                )
-            ]
-        );
-
-        $daemon->run();
-        $TYPES_REF = $stash->shift_stash();
-
-    }
-
-    return $TYPES_REF->{$comp_type_name}->{CT_ALIAS};
-
-}
-
-sub get_comp_type_name {
-
-    my $comp_name = shift;
-    my $daemon    = shift;
-    my $stash     = shift;
-
-    unless ( defined($DEFS_REF) ) {
-
-        $daemon->set_commands(
-            [
-                Siebel::Srvrmgr::Daemon::Command->new(
-                    {
-                        command => 'list comp def',
-                        action  => 'Siebel::Srvrmgr::Exporter::ListCompDef'
-                    }
-                )
-            ]
-        );
-
-        $daemon->run();
-        $DEFS_REF = $stash->shift_stash();
-
-    }
-
-    return $DEFS_REF->{$comp_name}->{CT_NAME};
+    print "\n", 'create component definition ', $comp->cc_alias(),
+      ' for component type ', $comp->ct_alias(),
+      ' component group ', $comp->cg_alias(), ' run mode ', $comp->cc_runmode(),
+      ' full name "', $comp->cc_name(), '" description "',
+      $comp->cc_desc_text(), '" with parameter ', join( ',', @params ), ";\n\n";
 
 }
