@@ -58,9 +58,6 @@ override 'do' => sub {
 
     my $tree = $self->get_parser()->get_parsed_tree();
 
-    my @comps
-      ;   # array of Siebel::Srvrmgr::ListParser::Output::ListComp::Comp objects
-
     foreach my $obj ( @{$tree} ) {
 
         if ( $obj->isa('Siebel::Srvrmgr::ListParser::Output::ListComp') ) {
@@ -127,6 +124,28 @@ L<Siebel::Srvrmgr::Daemon::Action::Serializable>
 
 =back
 
+=head1 AUTHOR
+
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+
+This file is part of Siebel Monitoring Tools.
+
+Siebel Monitoring Tools is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+Siebel Monitoring Tools is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
 
 =cut
 
