@@ -15,10 +15,13 @@ Siebel::Srvrmgr::ListParser - state model parser to idenfity which output type w
 =cut
 
 use Moose;
-use FSA::Rules;
 use Siebel::Srvrmgr::ListParser::OutputFactory;
 use Siebel::Srvrmgr::ListParser::Buffer;
 use Siebel::Srvrmgr::Regexes qw(SRVRMGR_PROMPT CONN_GREET);
+use Scalar::Util qw(weaken);
+use Siebel::Srvrmgr;
+use Log::Log4perl;
+use Siebel::Srvrmgr::ListParser::FSA;
 
 =pod
 
@@ -26,7 +29,7 @@ use Siebel::Srvrmgr::Regexes qw(SRVRMGR_PROMPT CONN_GREET);
 
 Siebel::Srvrmgr::ListParser is a state machine parser created to parse output of "list" commands executed through C<srvrmgr> program.
 
-The parser can idenfity different types of commands and their outputs from a buffer given as parameter to the module. Foreach 
+The parser can identify different types of commands and their outputs from a buffer given as parameter to the module. For each 
 type of output identified an L<Siebel::Srvrmgr::ListParser::Buffer> object will be created, identifying which type of command
 was executed and the raw information from it.
 
@@ -39,6 +42,8 @@ Siebel::Srvrmgr::ListParser expects to receive output from C<srvrmgr> program in
 limited number of commands and their outputs, raising an exception when those types cannot be identified. See subclasses
 of L<Siebel::Srvrmgr::ListParser::Output> to see which classes/types are available.
 
+Logging of this class can be enabled by using L<Siebel::Srvrmgr> logging feature.
+
 =head1 ATTRIBUTES
 
 =head2 parsed_tree
@@ -74,6 +79,8 @@ has 'has_tree' =>
 
 A regular expression reference of how the C<srvrmgr> prompt looks like.
 
+By default this regular expression value is defined by L<Siebel::Srvrmgr::Regexes>::SRVRMGR_PROMPT.
+
 =cut
 
 has 'prompt_regex' => (
@@ -91,6 +98,8 @@ has 'prompt_regex' => (
 A regular expression reference of how the first line of text received right after the login in one
 server (or enterprise).
 
+By default this regular expression value is defined by L<Siebel::Srvrmgr::Regexes>::CON_GREET.
+
 =cut
 
 has 'hello_regex' => (
@@ -147,16 +156,6 @@ has 'buffer' => (
 
 =pod
 
-=head2 is_warn_enabled
-
-A boolean value that is used for debugging purpouses during the parsing time. If enabled some debug messages may be printed during this phase.
-
-=cut
-
-has 'is_warn_enabled' => ( isa => 'Bool', is => 'ro', default => 0 );
-
-=pod
-
 =head1 METHODS
 
 =head2 is_cmd_changed
@@ -409,9 +408,9 @@ sub append_output {
 
 Parses one or more commands output executed through C<srvrmgr> program.
 
-Expects as parameter an array reference with the output of srvrmgr, including the command executed.
+Expects as parameter an array reference with the output of C<srvrmgr>, including the command executed.
 
-It will create an C<FSA::Rules> object to parse the given array reference, calling C<append_output> method for each C<Siebel::Srvrmgr::ListParser::Buffer> object
+It will create an L<FSA::Rules> object to parse the given array reference, calling C<append_output> method for each L<Siebel::Srvrmgr::ListParser::Buffer> object
 found.
 
 This method will raise an exception if a given output cannot be identified by the parser.
@@ -425,330 +424,30 @@ sub parse {
     # array ref
     my $data_ref = shift;
 
+    my $log_cfg = Siebel::Srvrmgr->logging_cfg();
+
+    die 'Could not start logging facilities'
+      unless ( Log::Log4perl->init_once( \$log_cfg ) );
+
+    my $logger = Log::Log4perl->get_logger('Siebel::Srvrmgr::ListParser');
+
     die "data parameter must be an array reference\n"
       unless ( ref($data_ref) eq 'ARRAY' );
 
-# :TODO:27/2/2012 15:06:20:: treat STDOUT messages adding a "warn" to notes method based on is_warn_enabled attribute
-    my $fsa = FSA::Rules->new(
-        first_line => {
-            do => sub {
-                print "Searching for useful data\n"
-                  if ( $ENV{SIEBEL_SRVRMGR_DEBUG} );
-            },
-            rules => [
-                command_submission => sub {
+    warn "received an empty buffer" unless ( @{$data_ref} );
 
-                    my $state = shift;
-                    my $line  = $state->notes('line');
-
-                    return ( $state->notes('line') =~
-                          $state->notes('parser')->get_prompt_regex() );
-
-                },
-                greetings => sub {
-
-                    my $state = shift;
-
-                    return ( $state->notes('line') =~
-                          $state->notes('parser')->get_hello_regex() );
-
-                },
-                first_line => sub { return 1 }
-            ],
-            message => 'Line read'
-
-        },
-        greetings => {
-            do => sub {
-
-                my $state = shift;
-
-                if ( defined( $state->notes('line') ) ) {
-
-                    $state->notes('parser')->set_buffer($state);
-                }
-            },
-            rules => [
-                command_submission => sub {
-
-                    my $state = shift;
-
-                    return ( $state->notes('line') =~
-                          $state->notes('parser')->get_prompt_regex() );
-
-                },
-                greetings => sub { return 1 }
-            ],
-            message => 'prompt found'
-        },
-        end => {
-            do    => sub { print "Enterprise says 'bye-bye'\n"; },
-            rules => [
-                first_line => sub {
-                    return 1;
-                  }
-            ],
-            message => 'EOF'
-        },
-        list_comp => {
-            do => sub {
-                my $state = shift;
-
-                $state->notes('parser')->set_buffer($state);
-
-            },
-            on_exit => sub {
-                my $state = shift;
-                $state->notes('parser')->is_cmd_changed(0);
-            },
-            rules => [
-                command_submission => sub {
-
-                    my $state = shift;
-
-                    return ( $state->notes('line') =~
-                          $state->notes('parser')->get_prompt_regex() );
-
-                },
-                list_comp => sub { return 1; }
-            ],
-            message => 'prompt found'
-        },
-        list_comp_types => {
-            do => sub {
-                my $state = shift;
-
-                $state->notes('parser')->set_buffer($state);
-
-            },
-            on_exit => sub {
-                my $state = shift;
-                $state->notes('parser')->is_cmd_changed(0);
-            },
-            rules => [
-                command_submission => sub {
-
-                    my $state = shift;
-
-                    return ( $state->notes('line') =~
-                          $state->notes('parser')->get_prompt_regex() );
-
-                },
-                list_comp_types => sub { return 1; }
-            ],
-            message => 'prompt found'
-        },
-        list_params => {
-            do => sub {
-                my $state = shift;
-
-                $state->notes('parser')->set_buffer($state);
-
-            },
-            on_exit => sub {
-                my $state = shift;
-                $state->notes('parser')->is_cmd_changed(0);
-            },
-            rules => [
-                command_submission => sub {
-
-                    my $state = shift;
-
-                    return ( $state->notes('line') =~
-                          $state->notes('parser')->get_prompt_regex() );
-
-                },
-                list_params => sub { return 1; }
-            ],
-            message => 'prompt found'
-        },
-        list_comp_def => {
-            do => sub {
-                my $state = shift;
-
-                $state->notes('parser')->set_buffer($state);
-
-            },
-            on_exit => sub {
-                my $state = shift;
-                $state->notes('parser')->is_cmd_changed(0);
-            },
-            rules => [
-                command_submission => sub {
-
-                    my $state = shift;
-
-                    return ( $state->notes('line') =~
-                          $state->notes('parser')->get_prompt_regex() );
-
-                },
-                list_comp_def => sub { return 1; }
-            ],
-            message => 'prompt found'
-        },
-        load_preferences => {
-            do => sub {
-                my $state = shift;
-
-                $state->notes('parser')->set_buffer($state);
-
-            },
-            on_exit => sub {
-                my $state = shift;
-                $state->notes('parser')->is_cmd_changed(0);
-            },
-            rules => [
-                command_submission => sub {
-
-                    my $state = shift;
-
-                    return ( $state->notes('line') =~
-                          $state->notes('parser')->get_prompt_regex() );
-
-                },
-                load_preferences => sub { return 1; }
-            ],
-            message => 'prompt found'
-        },
-        command_submission => {
-            do => sub {
-
-                my $state = shift;
-
-                my $cmd =
-                  ( $state->notes('line') =~
-                      $state->notes('parser')->get_prompt_regex() )[1];
-
-                if ( defined($cmd) ) {
-
-                    # removing spaces from command
-                    $cmd =~ s/^\s+//;
-                    $cmd =~ s/\s+$//;
-
-                    $state->notes('parser')->set_last_command($cmd);
-                }
-                else {
-
-                    if ( $state->notes('parser')->is_warn_enabled() ) {
-
-                        warn 'got prompt, but no command submitted in line '
-                          . $state->notes('line_num') . "\n"
-                          unless ( defined($cmd) );
-
-                    }
-
-                }
-
-            },
-            rules => [
-                list_comp => sub {
-
-                    my $state = shift;
-
-                    if ( $state->notes('parser')->get_last_command() eq
-                        'list comp' )
-                    {
-
-                        return 1;
-
-                    }
-                    else {
-
-                        return 0;
-
-                    }
-
-                },
-                list_comp_types => sub {
-
-                    my $state = shift;
-
-                    if (
-                        (
-                            $state->notes('parser')->get_last_command() eq
-                            'list comp types'
-                        )
-                        or ( $state->notes('parser')->get_last_command() eq
-                            'list comp type' )
-                      )
-                    {
-
-                        return 1;
-
-                    }
-                    else {
-
-                        return 0;
-
-                    }
-
-                },
-                list_params => sub {
-
-                    my $state = shift;
-
-           # :TODO:20/12/2011 18:05:33:: replace the regex for a precompiled one
-                    if ( $state->notes('parser')->get_last_command() =~
-                        /list\sparams(\sfor\sserver\s\w+\sfor\scomponent\s\w+)?/
-                      )
-                    {
-
-                        return 1;
-
-                    }
-                    else {
-
-                        return 0;
-
-                    }
-
-                },
-                list_comp_def => sub {
-
-                    my $state = shift;
-
-           # :TODO:20/12/2011 18:05:33:: replace the regex for a precompiled one
-                    if ( $state->notes('parser')->get_last_command() =~
-                        /list\scomp\sdefs?(\s\w+)?/ )
-                    {
-
-                        return 1;
-
-                    }
-                    else {
-
-                        return 0;
-
-                    }
-
-                },
-                load_preferences => sub {
-
-                    my $state = shift;
-
-                    if ( $state->notes('parser')->get_last_command() eq
-                        'load preferences' )
-                    {
-
-                        return 1;
-
-                    }
-                    else {
-
-                        return 0;
-
-                    }
-
-                },
-
-     # :TODO:06/07/2011 13:38:58:: add other possibilities here of list commands
-            ],
-            message => 'command submitted'
-        }
-    );
+    my $fsa = Siebel::Srvrmgr::ListParser::FSA->get_fsa($logger);
 
     $fsa->done( sub { ( $self->get_last_command() eq 'exit' ) ? 1 : 0 } );
 
+    # creates a image representing all the states used and their relationship
+#    if ( $logger->is_debug() ) {
+#
+#        my $graph = $fsa->graph( layout => 'neato', overlap => 'false' );
+#        $graph->as_png('pretty.png');
+#
+#    }
+
     my $state;
     my $line_number = 0;
 
@@ -758,8 +457,8 @@ sub parse {
 
             $state = $fsa->start();
 
-# :TODO:07/07/2011 14:56:04:: this should be changed to avoid circular references
             $state->notes( parser => $self );
+            weaken( $state->notes('parser') );
 
         }
 
@@ -788,12 +487,12 @@ sub parse {
 
 =head1 CAVEATS
 
-Checkout the POD for the C<Siebel::Srvrmgr::ListParser::Output> objects to see details about which kind of output is expected if you're getting errors from the parser. There 
+Checkout the POD for the L<Siebel::Srvrmgr::ListParser::Output> objects to see details about which kind of output is expected if you're getting errors from the parser. There 
 are details regarding how the settings of srvrmgr are expect for output of list commands.
 
 =head1 SEE ALSO
 
-=over 5 
+=over 6 
 
 =item *
 
@@ -815,6 +514,10 @@ L<Siebel::Srvrmgr::ListParser::OutputFactory>
 
 L<Siebel::Srvrmgr::ListParser::Buffer>
 
+=item *
+
+L<Siebel::Srvrmgr::Regexes>
+
 =back
 
 =head1 AUTHOR
@@ -842,5 +545,6 @@ along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
 
 =cut
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
+
+1;
