@@ -2,6 +2,7 @@ package Test::Condition;
 
 use Test::Most;
 use Siebel::Srvrmgr::ListParser;
+use Test::Moose 'has_attribute_ok';
 use base 'Test::Class';
 
 sub class { 'Siebel::Srvrmgr::Daemon::Condition' }
@@ -11,7 +12,7 @@ sub startup : Tests(startup => 1) {
     use_ok $test->class;
 }
 
-sub constructor : Tests(18) {
+sub constructor : Tests(24) {
 
     my $test  = shift;
     my $class = $test->class;
@@ -29,9 +30,20 @@ sub constructor : Tests(18) {
                 total_commands => 5
             }
         ),
-        'the constructor should suceed'
+        'the constructor works'
     );
 
+    my @attribs = (
+        'is_infinite', 'max_cmd_idx', 'total_commands', 'cmd_counter',
+        'output_used', 'cmd_sent'
+    );
+
+    foreach my $attrib (@attribs) {
+
+        has_attribute_ok( $condition, $attrib );
+
+    }
+
     ok( $condition->check(), 'check methods must return true' );
 
     is( $condition->is_output_used, 0, 'is_output_used must return false' );
