@@ -18,11 +18,8 @@ sub constructor : Tests(4) {
 
     can_ok( $class, 'new' );
 
-    #extended method tests
-    can_ok( $class, qw(parse get_attribs set_attribs) );
-
-	my @data = <Test::ListCompTypes::DATA>;
-	close(Test::ListCompTypes::DATA);
+    my @data = <Test::ListCompTypes::DATA>;
+    close(Test::ListCompTypes::DATA);
 
     ok(
         my $comps = $class->new(
@@ -35,6 +32,7 @@ sub constructor : Tests(4) {
         '... and the constructor should succeed'
     );
 
+    isa_ok( $comps, 'Siebel::Srvrmgr::ListParser::Output' );
     isa_ok( $comps, $class, '... and the object it returns' );
 
 }
