@@ -1,6 +1,7 @@
 package Test::LoadPreferences;
 
 use Test::Most;
+use Test::Moose qw(has_attribute_ok);
 use base 'Test::Class';
 
 sub class { 'Siebel::Srvrmgr::ListParser::Output::LoadPreferences' }
@@ -11,7 +12,7 @@ sub startup : Tests(startup => 1) {
     use_ok $test->class;
 }
 
-sub constructor : Tests(5) {
+sub constructor : Tests(6) {
 
     my $test  = shift;
     my $class = $test->class;
@@ -21,8 +22,8 @@ sub constructor : Tests(5) {
     #extended method tests
     can_ok( $class, qw(parse get_location set_location) );
 
-	my @data = <Test::LoadPreferences::DATA>;
-	close(Test::LoadPreferences::DATA);
+    my @data = <Test::LoadPreferences::DATA>;
+    close(Test::LoadPreferences::DATA);
 
     ok(
         my $prefs = $class->new(
@@ -35,9 +36,15 @@ sub constructor : Tests(5) {
         '... and the constructor should succeed'
     );
 
+    has_attribute_ok( $prefs, 'location' );
+
     isa_ok( $prefs, $class, '... and the object it returns' );
 
-	is($prefs->get_location(), 'C:\Siebel\8.0\web client\BIN\.Siebel_svrmgr.pref', 'get_location returns the correct data');
+    is(
+        $prefs->get_location(),
+        'C:\Siebel\8.0\web client\BIN\.Siebel_svrmgr.pref',
+        'get_location returns the correct data'
+    );
 
 }
 
